<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */

include 'functions.php';

/**
 * 
 * Connect to MySQL.
 * 
 */

$pdo = pdo_connect_mysql();

/**
 * 
 * If the GET request "id" exists (poll id).
 * 
 */

if (isset($_GET['id'])) {

/**
 * 
 * MySQL query that selects the poll records by the GET request "id".
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM polls WHERE approved = 1 AND id = ?');
$stmt->execute([$_GET['id']]);

/**
 * 
 * Fetch the record.
 * 
 */

$poll = $stmt->fetch(PDO::FETCH_ASSOC);

/**
 * 
 * Check if the poll record exists with the id specified.
 * 
 */

if ($poll) {

/**
 * 
 * MySQL Query that will get all the answers from the "poll_answers" table.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM poll_answers WHERE poll_id = ? ORDER BY votes DESC');
$stmt->execute([ $_GET['id'] ]);

/**
 * 
 * Fetch all poll answers.
 * 
 */

$poll_answers = $stmt->fetchAll(PDO::FETCH_ASSOC);

/**
 * 
 * Total number of votes, will be used to calculate the percentage.
 * 
 */

$total_votes = 0;
foreach ($poll_answers as $poll_answer) {

/**
 * 
 * Every poll answers votes will be added to total votes.
 * 
 */

$total_votes += $poll_answer['votes']; }
} else {
exit('' . _POLLNOTEXIST . ''); }
} else {
exit('' . _NOPOLLID . ''); } ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="">
<meta name="keywords" content="">
<meta name="author" content="Mike">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />

<style>
.responsive-poll { 
width:30% }

@media (max-width: 1000px) { 
.responsive-poll { width:100% }}
</style>

<?php require_once 'header.php'; ?>

<title><?= _STATS ?></title>

<p>&nbsp;</p>
<div class="inner-wrapper spacer responsive-poll" style="border-radius:12px">

<h2 class="center"><?=$poll['title']?></h2>
<hr />

<h3 class="center"><?=$poll['description']?></h3>

<h3 class="center">- <?= _VOTES ?> -</h3>
<?php foreach ($poll_answers as $poll_answer) { ?>
<div class="center">
<p class="gentextcolor"><?= $poll_answer['title'] ?>: ( <?= $poll_answer['votes'] ?> )</p>
</div>
<?php } ?>
</div>
<p>&nbsp;</p>

<?php require_once 'footer.php';
