<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */

include 'functions.php';

/**
 * 
 * Connect to MySQL.
 * 
 */

$pdo = pdo_connect_mysql();

/**
 * 
 * Output message.
 * 
 */

$msg = '';

/**
 * 
 * If the GET request "id" exists (poll id).
 * 
 */

if (isset($_GET['id'])) {

/**
 * 
 * MySQL query that selects the poll records by the GET request "id". 
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM polls WHERE approved = 1 AND id = ?');
$stmt->execute([$_GET['id']]);

/**
 * 
 * Fetch the record.
 * 
 */

$poll = $stmt->fetch(PDO::FETCH_ASSOC);

/**
 * 
 * Check if the poll record exists with the id specified.
 * 
 */

if ($poll) {

/**
 * 
 * MySQL query that selects all the poll answers.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM poll_answers WHERE poll_id = ?');
$stmt->execute([$_GET['id']]);

/**
 * 
 * Fetch all the poll anwsers.
 * 
 */

$poll_answers = $stmt->fetchAll(PDO::FETCH_ASSOC);

/**
 * 
 * If the user clicked the "Vote" button.
 * 
 */

if (isset($_POST['poll_answer'])) {

/**
 * 
 * Check if the poll has expired and the user has already voted.
 * 
 */

if ($poll['expires'] && date('Y-m-d H:i:s') >= $poll['expires']) {

/**
 * 
 * The poll expire datetime is less than the current server datetime.
 * 
 */

$msg = 'This poll has expired! You can no longer vote!';
} else if (isset($_COOKIE['poll' . $_GET['id']]) && one_vote_per_poll) {

/**
 * 
 * User has already voted.
 * 
 */

$msg = 'You have already voted!';
} else if (date('Y-m-d H:i:s') < $poll['start_date']) {

/**
 * 
 * Poll has not yet started.
 * 
 */

$msg = 'This poll has not yet started!';
} else {

/**
 * 
 * Update and increase the vote for the answer the user voted for.
 * 
 */

if (is_array($_POST['poll_answer'])) {
foreach ($_POST['poll_answer'] as $poll_answer) {
$stmt = $pdo->prepare('UPDATE poll_answers SET votes = votes + 1 WHERE id = ?');
$stmt->execute([$poll_answer]); }
} else {
$stmt = $pdo->prepare('UPDATE poll_answers SET votes = votes + 1 WHERE id = ?');
$stmt->execute([$_POST['poll_answer']]); }

/**
 * 
 * Set cookie to prevent user from voting multiple times on te same poll.
 * 
 */

setcookie('poll' . $_GET['id'], true, time() + (10 * 365 * 24 * 60 * 60));

/**
 * 
 * Redirect user to the result page.
 * 
 */

header('Location: result.php?id=' . $_GET['id']);
exit; }}
} else {
exit('Poll with that ID does not exist.'); }
} else {
exit('No poll ID specified.'); } ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="">
<meta name="keywords" content="">
<meta name="author" content="">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
<style>.responsive-poll { width:30% } @media (max-width: 1000px) { .responsive-poll { width:100% }}</style>
<?php require_once 'header.php'; ?>
<title><?= _VOTE ?></title>
<div class="inner-wrapper center responsive-poll" style="border-radius:12px">
<p>&nbsp;</p>

<h2 class="center"><?= $poll['title'] ?></h2>
<hr />

<p class="center"><?= $poll['description'] ?></p>

<form action="vote.php?id=<?= $_GET['id'] ?>" method="post">

<?php for ($i = 0; $i < count($poll_answers); $i++): ?>

<p class="left" style="padding-left:20px">
<input type="<?= $poll['num_choices'] > 1 ? 'checkbox' : 'radio' ?>" name="poll_answer<?= $poll['num_choices'] > 1 ? '[]' : '' ?>" value="<?= $poll_answers[$i]['id'] ?>">
<?= $poll_answers[$i]['title'] ?></p>

<?php endfor; ?>
<div>
<p class="center"><input type="submit" value="<?= _VOTE ?>"></p>
<p class="center"><a href="result.php?id=<?= $poll['id'] ?>"><?= _VIEWRESULT ?></a></p>
</div>
<p>&nbsp;</p>
</div>
</form>

<?php if ($msg): ?>
<p><?= $msg ?></p>
<?php endif; ?>

<?php if ($poll['num_choices'] > 1): ?>

<script>
document.querySelectorAll('[name="poll_answer[]"]').forEach(function(element) {
element.onchange = function(event) {
if (document.querySelectorAll('[name="poll_answer[]"]:checked').length+1 > <?= $poll['num_choices'] ?>) {
document.querySelectorAll('[name="poll_answer[]"]:not(:checked)').forEach(function(element) {
element.disabled = true;
});
} else {
document.querySelectorAll('[name="poll_answer[]"]').forEach(function(element) {
element.disabled = false;
});
}
};
});
</script>
<?php endif; ?>

<?php require_once 'footer.php';