<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */

if (!isset($_SERVER['HTTP_REFERER'])) { 
echo "<script> window.location.replace('../../index.php') </script>";
exit;}

include 'main.php';

$msg = '';

/**
 * 
 * Check if POST data exists.
 * 
 */

if (isset($_POST['title'])) {

/**
 * 
 * Post data exists, insert a new record
 * Check all POST data variables.
 * 
 */

$title = $_POST['title'];
$description = isset($_POST['description']) ? $_POST['description'] : '';
$expires = isset($_POST['expires'], $_POST['expires_enabled']) && $_POST['expires_enabled'] ? $_POST['expires'] : NULL;
$num_choices = isset($_POST['num_choices']) ? $_POST['num_choices'] : 1;
$start_date = isset($_POST['start_date']) ? $_POST['start_date'] : date('Y-m-d\TH:i');
$approved = approval_required ? 0 : 1;

/**
 * 
 * Insert new record into the "polls" table.
 * 
 */

$stmt = $pdo->prepare('INSERT INTO polls (title, description, expires, start_date, approved, num_choices) VALUES (?, ?, ?, ?, ?, ?)');
$stmt->execute([ $title, $description, $expires, $start_date, $approved, $num_choices ]);

/**
 * 
 * Below will get the last insert ID, 
 * which will be the poll id.
 * 
 */

$poll_id = $pdo->lastInsertId();

/**
 * 
 * Iterate the post data and add the answers.
 * 
 */

foreach($_POST as $k => $v) {

/**
 * 
 * If the answer is empty, there is no need to insert.
 * 
 */

if (strpos($k, 'answer') === false || empty($v)) continue;

/**
 * 
 * Add answer to the "poll_answers" table.
 * 
 */

$stmt = $pdo->prepare('INSERT INTO poll_answers (poll_id, title) VALUES (?, ?)');
$stmt->execute([ $poll_id, $v ]); }

/**
 * 
 * Output success message / approval message.
 * 
 */

if (!$approved) {
$msg = 'Your poll is awaiting approval!';
} else {
$msg = 'Created Successfully!'; }} ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="">
<meta name="keywords" content="">
<meta name="author" content="Mike">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />

<style>
.update form .add_answer {
text-decoration: none;
padding-bottom: 15px;
font-size: 14px;
color: #7d838b;
font-weight: 600;
}

.update form .add_answer i {
padding-right: 5px;
}

.update form .add_answer:hover {
color: #70767e;
}
</style>

<title><?= _CREATEPOLL ?></title>

<?php require_once 'header.php'; 
require_once 'poll-menu.php'; ?>

<div class="mini-container center">

<div class="column-title"><h1 class="coltitlecolor center"><?= _CREATEPOLL ?></h1></div>

<form action="" method="post" style="border:0">

<div class="center">

<label for="title" class="gentextcolor"><?= _TITLE ?></label><br>
<input type="text" name="title" id="title" class="spacer mini-container" placeholder="<?= _TITLE ?>" required>
<br><br>
<label for="description" class="gentextcolor"><?= _BRIEFDESC ?></label><br>
<input type="text" name="description" class="spacer mini-container" id="description" placeholder="<?= _BRIEFDESC ?>">
<br><br>
<label for="answers" class="gentextcolor"><?= _ANSWERS ?></label><br>
<div class="answers">
<p><input type="text" name="answer_1" placeholder="<?= _ANSWERONE ?>" required></p>
</div>
<p><a href="#" class="add_answer"><i class="fas fa-plus"></i> <?= _ADDANSWER ?></a></p>
<br>
<label for="start_date" class="gentextcolor"><?= _STARTDATE ?></label><br>
<input type="datetime-local" id="start_date" name="start_date" value="<?=date('Y-m-d\TH:i')?>">
<br><br>
<label for="expires_enabled" class="gentextcolor"><?= _EXPIRES ?></label><br>
<input type="checkbox" id="expires_enabled" name="expires_enabled">
<input type="datetime-local" id="expires" name="expires" value="<?=date('Y-m-d\TH:i')?>" min="<?=date('Y-m-d\TH:i')?>">
<br><br>
<label for="num_choices" class="gentextcolor"><?= _NUMBEROFCHOICES ?></label><br>
<input type="number" id="num_choices" name="num_choices" value="1">
<br><br>
<input type="submit" value="Create">
</div>
</form>

<?php if ($msg): ?>
<p><?=$msg?></p>
<?php endif; ?>

</div>

<script>
document.querySelector('.add_answer').onclick = function(event) {
event.preventDefault();
let num_answers = document.querySelector('.answers').childElementCount + 1;
document.querySelector('.answers').insertAdjacentHTML('beforeend', '<p><input type="text" name="answer_' + num_answers + '" placeholder="Answer ' + num_answers + '"></p>');
};
</script>

<?php require_once 'footer.php';
