<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */

if (!isset($_SERVER['HTTP_REFERER'])) {echo "<script> window.location.replace('../../index.php') </script>";
exit;}

include 'main.php';

/**
 * 
 * Retrieve all polls submitted for the current day.
 * 
 */

$stmt = $pdo->prepare('SELECT p.*, GROUP_CONCAT(pa.title) AS answers FROM polls p LEFT JOIN poll_answers pa ON pa.poll_id = p.id WHERE cast(p.submit_date as DATE) = cast(now() as DATE) GROUP BY p.id ORDER BY p.submit_date DESC');
$stmt->execute();
$polls = $stmt->fetchAll(PDO::FETCH_ASSOC);

/**
 * 
 * Retrieve the total number of polls that are awaiting approval.
 * 
 */

$stmt = $pdo->prepare('SELECT COUNT(*) AS total FROM polls WHERE approved = 0');
$stmt->execute();
$awaiting_approval = $stmt->fetchColumn();

/**
 * 
 * Retrieve the total number of polls.
 * 
 */

$stmt = $pdo->prepare('SELECT COUNT(*) AS total FROM polls');
$stmt->execute();
$polls_total = $stmt->fetchColumn();

/**
 * 
 * Retrieve the total number of polls.
 * 
 */

$stmt = $pdo->prepare('SELECT COUNT(*) AS total FROM poll_answers');
$stmt->execute();
$poll_answers_total = $stmt->fetchColumn();

/**
 * 
 * Retrieve all the polls awaiting approval.
 * 
 */

$stmt = $pdo->prepare('SELECT p.*, GROUP_CONCAT(pa.title) AS answers FROM polls p LEFT JOIN poll_answers pa ON pa.poll_id = p.id WHERE p.approved = 0 GROUP BY p.id ORDER BY p.submit_date DESC');
$stmt->execute();
$polls_awaiting_approval = $stmt->fetchAll(PDO::FETCH_ASSOC); ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="">
<meta name="keywords" content="">
<meta name="author" content="">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
<title><?= _POLLSDASHBOARD ?></title>

<?php require_once 'header.php'; 
require_once 'poll-menu.php'; ?>

<div class="column-title"><h2 class="coltitlecolor center"><?= _POLLSDASHBOARD ?></h2></div>

<div class="dashboard center mini-container" style="margin:0 auto">

<table>
<thead>
<tr class="column-title coltitlecolor">
<th scope="col"><?= _TODAYSPOLLS ?></th>
<th scope="col"><?= _AWAITINGAPPROVAL ?></th>
<th scope="col"><?= _TOTALPOLLS ?></th>
<th scope="col"><?= _TOTALANSWERS ?></th>
</tr>
</thead>
<tr style="background:#f1f1f1">
<td data-label="<?= _TODAYSPOLLS ?>:"><?=number_format(count($polls))?></td>           
<td data-label="<?= _AWAITINGAPPROVAL ?>:"><?=number_format($awaiting_approval)?></td>           
<td data-label="<?= _TOTALPOLLS ?>:"><?=number_format($polls_total)?></td>        
<td data-label="<?= _TOTALANSWERS ?>:"><?=number_format($poll_answers_total)?></td>

</tr></table>        

</div>

<h2 class="center"><?= _TODAYSPOLLS ?></h2>

<div class="content-block">
<div class="table">
<table>
<thead>
<tr class="column-title coltitlecolor">
<th scope="col"><?= _TITLE ?></th>
<th scope="col"><?= _DESCRIPTION ?></th>
<th scope="col"><?= _ANSWERS ?></th>
<th scope="col"><?= _APPROVED ?></th>
<th scope="col"><?= _EXPIRES ?></th>
<th scope="col"><?= _DATE ?></th>
<th scope="col"><?= _ACTIONS ?></th>
</tr>
</thead>
<tbody>
<?php if (empty($polls)): ?>
<tr style="background:#f1f1f1">
<td colspan="7" style="text-align:center;"><?= _NOPOLLS ?></td>
</tr>
<?php else: ?>
<?php foreach ($polls as $poll): ?>
<tr style="background:#f1f1f1" class="card">
<td data-label="<?= _TITLE ?>:"> <?=htmlspecialchars($poll['title'], ENT_QUOTES)?></td>
<td data-label="<?= _DESCRIPTION ?>:"> <?=nl2br(htmlspecialchars($poll['description'], ENT_QUOTES))?></td>
<td data-label="<?= _ANSWERS ?>:"> <?=$poll['answers']?></td>
<td data-label="<?= _APPROVED ?>?"><?=$poll['approved']?'Yes':'No'?></td>
<td data-label="<?= _EXPIREDATE ?>:"><?=$poll['expires'] ? date('F j, Y H:ia', strtotime($poll['expires'])) : 'Never'?></td>
<td data-label="<?= _SUBMITDATE ?>:"><?=date('F j, Y H:ia', strtotime($poll['submit_date']))?></td>
<td>
<p>
<a href="result.php?id=<?=$poll['id']?>"><span class="black"><?= _VIEW ?></span></a>
<a href="poll.php?id=<?=$poll['id']?>"><span class="black"><?= _EDIT ?></span></a>
</p>
<p><a href="polls.php?delete=<?=$poll['id']?>"><span class="black"><?= _DELETE ?></span></a></p>
<?php if (!$poll['approved']): ?>
<p><a href="polls.php?approve=<?=$poll['id']?>"><span class="black"><?= _APPROVE ?></span></a></p>
<?php endif; ?>
</td>
</tr>
<?php endforeach; ?>
<?php endif; ?>
</tbody>
</table>
</div>
</div>

<h2 style="margin-top:40px" class="center"><?= _AWAITINGAPPROVAL ?></h2>

<div class="content-block">
<div class="table">
<table>
<thead>
<tr class="column-title coltitlecolor" style="width:100%">
<th scope="col"><?= _TITLE ?></th>
<th scope="col"><?= _DESCRIPTION ?></th>
<th scope="col"><?= _ANSWERS ?></th>
<th scope="col"><?= _APPROVED ?></th>
<th scope="col"><?= _EXPIRES ?></th>
<th scope="col"><?= _DATE ?></th>
<th scope="col"><?= _ACTIONS ?></th>
</tr>
</thead>
<tbody>
<?php if (empty($polls_awaiting_approval)): ?>
<tr style="background:#f1f1f1">
<td colspan=7" style="text-align:center;"><?= _NOPOLLSAWAITING ?></td>
</tr>
<?php else: ?>
<?php foreach ($polls_awaiting_approval as $poll): ?>
<tr style="background:#f1f1f1">
<td data-label="<?= _TITLE ?>:"> <?=htmlspecialchars($poll['title'], ENT_QUOTES)?></td>
<td data-label="<?= _DESCRIPTION ?>:"> <?=nl2br(htmlspecialchars($poll['description'], ENT_QUOTES))?></td>
<td data-label="<?= _ANSWERS ?>:"> <?=$poll['answers']?></td>
<td data-label="<?= _APPROVED ?>?"><?=$poll['approved']?'Yes':'No'?></td>
<td data-label="<?= _EXPIREDATE ?>:"><?=$poll['expires'] ? date('F j, Y H:ia', strtotime($poll['expires'])) : 'Never'?></td>
<td data-label="<?= _SUBMITDATE ?>:"><?=date('F j, Y H:ia', strtotime($poll['submit_date']))?></td>
<td>
<p><a href="result.php?id=<?=$poll['id']?>" target="_blank" style="text-decoration:none"><span class="button"><?= _VIEW ?></span></a>
<a href="poll.php?id=<?=$poll['id']?>" style="text-decoration:none"><span class="button"><?= _EDIT ?></span></a></p>
<p><a href="polls.php?delete=<?=$poll['id']?>" style="text-decoration:none"><span class="button"><?= _DELETE ?></span></a></p>
<?php if (!$poll['approved']): ?>
<p><a href="polls.php?approve=<?=$poll['id']?>" style="text-decoration:none"><span class="button"><?= _APPROVE ?></span></a></p>
<?php endif; ?>
</td>
</tr>
<?php endforeach; ?>
<?php endif; ?>
</tbody>
</table>
</div>
</div>

<?= require_once 'footer.php';
