<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */

if (!isset($_SERVER['HTTP_REFERER'])) {echo "<script> window.location.replace('../../index.php') </script>";
exit;}

include 'main.php';

/**
 * 
 * Default poll values.
 * 
 */

$poll = [
'title' => '',
'description' => '',
'expires' => date('Y-m-d\TH:i:s'),
'submit_date' => date('Y-m-d\TH:i:s'),
'start_date' => date('Y-m-d\TH:i:s'),
'approved' => 0,
'num_choices' => 1
];
$poll_answers = [];
if (isset($_GET['id'])) {

/**
 * 
 * Retrieve the poll from the database.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM polls WHERE id = ?');
$stmt->execute([ $_GET['id'] ]);
$poll = $stmt->fetch(PDO::FETCH_ASSOC);

/**
 * 
 * Retrieve the poll answers from the database.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM poll_answers WHERE poll_id = ?');
$stmt->execute([ $_GET['id'] ]);
$poll_answers = $stmt->fetchAll(PDO::FETCH_ASSOC);

/**
 * 
 * ID param exists, edit an existing poll.
 * 
 */

$page = 'Edit';
if (isset($_POST['submit'])) {

/**
 * 
 * Update the poll.
 * 
 */

$stmt = $pdo->prepare('UPDATE polls SET title = ?, description = ?, expires = ?, submit_date = ?, start_date = ?, approved = ?, num_choices = ? WHERE id = ?');
$expires = isset($_POST['expires_enabled']) ? date('Y-m-d H:i:s', strtotime($_POST['expires'])) : NULL;
$stmt->execute([ $_POST['title'], $_POST['description'], $expires, date('Y-m-d H:i:s', strtotime($_POST['submit_date'])), date('Y-m-d H:i:s', strtotime($_POST['start_date'])), $_POST['approved'], $_POST['num_choices'], $_GET['id'] ]);

/**
 * 
 * Get the answers and convert the multiline string to an array, 
 * so we can add each answer to the "poll_answers" <table class=""></table>
 * 
 */

$answers = isset($_POST['answers']) ? explode(PHP_EOL, $_POST['answers']) : '';

/**
 * 
 * New answers array.
 * 
 */

$new_answers = [];

/**
 * 
 * Iterate the answers array.
 * 
 */

foreach ($answers as $answer) {

/**
 * 
 * If the answer is empty, there is no need to insert.
 * 
 */

if (empty($answer)) continue;

/**
 * 
 * Add answer to the "poll_answers" table.
 * 
 */

$stmt = $pdo->prepare('INSERT IGNORE INTO poll_answers (poll_id, title) VALUES (?, ?)');
$stmt->execute([ $_GET['id'], $answer ]);

/**
 * 
 * Add answer to array.
 * 
 */

$new_answers[] = $answer; }
if ($new_answers) {

/**
 * 
 * Delete the removed answers from the database. 
 * 
 */

$stmt = $pdo->prepare('DELETE FROM poll_answers WHERE poll_id = ? AND !FIND_IN_SET(title, ?)');
$stmt->execute([ $_GET['id'], implode(',', $new_answers) ]); }
header('Location: polls.php');
exit; }
if (isset($_POST['delete'])) {

/**
 * 
 * Delete the poll.
 * 
 */

$stmt = $pdo->prepare('DELETE p, pa FROM polls p LEFT JOIN poll_answers pa ON pa.poll_id = p.id WHERE p.id = ?');
$stmt->execute([ $_GET['id'] ]);
header('Location: polls.php');
exit; }
} else {

/**
 * 
 * Create a new poll.
 * 
 */

$page = 'Create';
if (isset($_POST['submit'])) {
$stmt = $pdo->prepare('INSERT INTO polls (title, description, expires, submit_date, start_date, approved, num_choices) VALUES (?,?,?,?,?,?,?)');
$expires = isset($_POST['expires_enabled']) ? date('Y-m-d H:i:s', strtotime($_POST['expires'])) : NULL;
$stmt->execute([ $_POST['title'], $_POST['description'], $expires, date('Y-m-d H:i:s', strtotime($_POST['submit_date'])), date('Y-m-d H:i:s', strtotime($_POST['start_date'])), $_POST['approved'], $_POST['num_choices'] ]);

/**
 * 
 * Below will get the last insert ID, which is the poll id. 
 * 
 */

$poll_id = $pdo->lastInsertId();

/**
 * 
 * Get the answers and convert the multiline string to an array, 
 * so we can add each answer to the "poll_answers" table. 
 * 
 */

$answers = isset($_POST['answers']) ? explode(PHP_EOL, $_POST['answers']) : '';
foreach ($answers as $answer) {

/**
 * 
 * If the answer is empty there is no need to insert.
 * 
 */

if (empty($answer)) continue;

/**
 * 
 * Add answer to the "poll_answers" table. 
 * 
 */

$stmt = $pdo->prepare('INSERT INTO poll_answers (poll_id, title) VALUES (?, ?)');
$stmt->execute([ $poll_id, $answer ]); }
header('Location: polls.php');
exit; }} ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="">
<meta name="keywords" content="">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
<title><?= _POLLS ?></title>

<?php require_once 'header.php'; 
require_once 'poll-menu.php'; ?>

<div class="column-title"><h1 class="coltitlecolor center"><?=$page?> <?= _POLLS ?></h1></div>
<form action="" method="post" style="border:0">
<div class="mini-container center spacer">
<label for="title" class="gentextcolor"><?= _TITLE ?></label><br>
<input id="title" type="text" name="title" placeholder="<?= _TITLE ?>" value="<?=htmlspecialchars($poll['title'], ENT_QUOTES)?>" required>
<br><br>
<label for="description" class="gentextcolor"><?= _DESC ?></label><br>
<textarea id="description" name="description" placeholder="Description" class="mini-container spacer"><?=htmlspecialchars($poll['description'], ENT_QUOTES)?></textarea>
<br><br>
<label for="answers" class="gentextcolor"><?= _ANSWERS ?></label><br>
<textarea id="answers" name="answers" placeholder="<?= _ANSWERS ?>" style="height:200px" class="mini-container spacer"><?php foreach($poll_answers as $poll_answer): ?><?=htmlspecialchars($poll_answer['title'], ENT_QUOTES) . PHP_EOL?><?php endforeach; ?></textarea>
<br><br>
<label for="expires_enabled" class="gentextcolor"><?= _EXPIRES ?></label><br>
<input id="expires_enabled" type="checkbox" name="expires_enabled" placeholder="<?= _EXPIRESENABLED ?>"<?=isset($poll['expires']) ? ' checked' : ''?>>
<input id="expires" type="datetime-local" name="expires" value="<?=date('Y-m-d\TH:i:s')?>">
<br><br>
<label for="submit_date" class="gentextcolor"><?= _DATESUBMITTED ?></label><br>
<input id="submit_date" type="datetime-local" name="submit_date" value="<?=date('Y-m-d\TH:i:s', strtotime($poll['submit_date']))?>" required>
<br><br>
<label for="start_date" class="gentextcolor"><?= _STARTDATE ?></label><br>
<input id="start_date" type="datetime-local" name="start_date" value="<?=date('Y-m-d\TH:i:s', strtotime($poll['start_date']))?>" required>
<br><br>
<label for="num_choices" class="gentextcolor"><?= _NUMBEROFCHOICES ?></label><br>
<input id="num_choices" type="number" name="num_choices" placeholder="Number of Choices" value="<?=$poll['num_choices']?>" required>
<br><br>
<label for="approved" class="gentextcolor"><?= _APPROVED ?></label><br>
<select id="approved" name="approved" required>
<option value="0"<?=$poll['approved']==0?' selected':''?>><?= _NO ?></option>
<option value="1"<?=$poll['approved']==1?' selected':''?>><?= _YES ?></option>
</select>
<br><br>

<div class="submit-btns">
<input type="submit" name="submit" value="Submit">
<?php if ($page == 'Edit') { ?>
<input type="submit" name="delete" value="<?= _DELETE ?>" class="delete">
<?php } ?>
</div>
</div>

</form>

<?php require_once 'footer.php';
