<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */

include 'main.php';

/**
 * 
 * Delete poll.
 * 
 */

if (isset($_GET['delete'])) {
$stmt = $pdo->prepare('DELETE p, pa FROM polls p LEFT JOIN poll_answers pa ON pa.poll_id = p.id WHERE p.id = ?');
$stmt->execute([ $_GET['delete'] ]);
header('Location: polls.php');
exit; }

/**
 * 
 * Approve poll.
 * 
 */

if (isset($_GET['approve'])) {
$stmt = $pdo->prepare('UPDATE polls SET approved = 1 WHERE id = ?');
$stmt->execute([ $_GET['approve'] ]);
header('Location: polls.php');
exit; }

/**
 * 
 * SQL query that will retrieve all the polls 
 * from the database ordered by the submit_date column.
 * 
 */

$stmt = $pdo->prepare('SELECT p.*, GROUP_CONCAT(pa.title) AS answers FROM polls p LEFT JOIN poll_answers pa ON pa.poll_id = p.id GROUP BY p.id ORDER BY p.submit_date DESC');
$stmt->execute();
$polls = $stmt->fetchAll(PDO::FETCH_ASSOC); ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="">
<meta name="keywords" content="">
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no" />
<title><?= _POLLLISTING ?></title>
<?php require_once 'header.php';
require_once 'poll-menu.php'; ?>

<div class="column-title"><h1 class="coltitlecolor center"><?= _POLLS ?></h1></div>
<br>

<div class="content-block mini-container full">
<div class="table">
<table>
<thead>
<tr class="column-title coltitlecolor">
<th scope="col"><?= _TITLE ?></th>
<th scope="col"><?= _DESCRIPTION ?></th>
<th scope="col"><?= _ANSWERS ?></th>
<th scope="col"><?= _APPROVED ?></th>
<th scope="col"><?= _EXPIRES ?></th>
<th scope="col"><?= _DATE ?></th>
<th scope="col"><?= _ACTIONS ?></th>
</tr>
</thead>
<tbody>
<?php if (empty($polls)): ?>
<tr>
<td colspan="8" style="text-align:center;"><p><?= _NOPOLLS ?></p></td>
</tr>
<?php else: ?>
<?php foreach ($polls as $poll): ?>
<tr style="background:#f1f1f1; border:1px solid #888;">
<td data-label="<?= _TITLE ?>:"> <?=htmlspecialchars($poll['title'], ENT_QUOTES)?></td>
<td data-label="<?= _DESCRIPTION ?>:"> <?=nl2br(htmlspecialchars($poll['description'], ENT_QUOTES))?></td>
<td data-label="<?= _ANSWERS ?>:"> <?=$poll['answers']?></td>
<td data-label="<?= _APPROVED ?>?"><?=$poll['approved']?'Yes':'No'?></td>
<td data-label="<?= _EXPIREDATE ?>:"><?=$poll['expires'] ? date('F j, Y H:ia', strtotime($poll['expires'])) : 'Never'?></td>
<td data-label="<?= _SUBMITDATE ?>:"><?=date('F j, Y H:ia', strtotime($poll['submit_date']))?></td>
<td>
<p><a href="result.php?id=<?=$poll['id']?>"><span class="black">[<?= _VIEW ?>]</span></a>
<a href="poll.php?id=<?=$poll['id']?>"><span class="black">[<?= _EDIT ?>]</span></a></p>
<p><a href="polls.php?delete=<?=$poll['id']?>"><span class="black">[<?= _DELETE ?>]</span></a></p>
<?php if (!$poll['approved']) { ?>
<p><a href="polls.php?approve=<?=$poll['id']?>"><span class="black">[<?= _APPROVE ?>]</span></a></p>                       
<?php } ?>

</td>
</tr>

<?php endforeach; ?>
<?php endif; ?>
</tbody>
</table>
</div>
</div>

<?php require_once 'footer.php';
