<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 */

require_once 'main.php'; ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">

<?php $sql = "SELECT lang FROM website"; 
$result = $conn->query($sql); 
if ($result->num_rows > 0) { 
while ($row = $result->fetch_assoc()) { 
$lang = $row['lang']; }}
require_once 'lang/' . $lang . '.php'; ?>

<title><?= _AUTHENACCOUNT ?></title>

<?php 
/**
 * 
 * If the login attempts of 5 has
 * been met then do not allow further
 * attempts and display a message.
 * 
 */

$login_attempts = loginAttempts($conn, FALSE);
if ($login_attempts && $login_attempts['attempts_left'] <= 0) {
require_once 'plainheader.php'; ?>
<h2 class="card gentextcolor" style="text-align:center"><?= _CANNOTLOGINNOW ?></h2>
<?php exit(); }

if (!isset($_POST['token']) || $_POST['token'] != $_SESSION['token']) {
require_once 'plainheader.php'; ?>
<h3 class="card gentextcolor" style="text-align:center"><?= _INCORRECTTOKEN; $login_attempts = loginAttempts($conn);echo '</h3>';
exit(); }

/**
 * 
 * Now we check if the data from the login form was submitted, 
 * isset() will check if the data exists.
 * 
 */

if (!isset($_POST['username'], $_POST['password'])) {

/**
 * 
 * Could not get the data that should have been sent.
 * 
 */

require_once 'plainheader.php'; ?>
<h3 class="card gentextcolor" style="text-align:center"><?= _PLEASEFILLUSERNAMEPASSWORD ?></h3>
<?php exit(); }
$stmt = $conn->prepare('SELECT id, password, rememberme, activation_code, role FROM accounts WHERE username = ?');

/**
 * 
 * Bind parameters (s = string, i = int, b = blob, etc), 
 * in our case the username is a string so we use "s"
 * 
 */

$stmt->bind_param('s', $_POST['username']);
$stmt->execute();

/**
 * 
 * Store the result so we can check if the account exists in the database.
 * 
 */

$stmt->store_result();

/**
 * 
 * Check if the account exists:
 * 
 */

if ($stmt->num_rows > 0) {
$stmt->bind_result($id, $password, $rememberme, $activation_code, $role);
$stmt->fetch();
$stmt->close();

/**
 * 
 * Account exists, now we verify the password.
 * Note: remember to use password_hash 
 * in your registration file to store the hashed passwords.
 * 
 */

if (password_verify($_POST['password'], $password)) {

/**
 * 
 * Check if the account is activated.
 * Define for new accounts.
 * 
 */

if (account_activation && $activation_code != 'activated') {

/**
 * 
 * User has not activated their account, output the message.
 * 
 */

require_once 'plainheader.php';
echo '<div class="login card spacer center">'; ?>
<?= _PLEASEACTIVATEACCOUNT;
echo '<a href="resendactivation.php"> here</a>'; ?>
<?= _TORESENDEMAIL;
echo '</div>';
} else {

/**
 * 
 * Verification success! User has loggedin!
 * Create sessions so we know the user is logged in, 
 * they basically act like cookies but remember the data on the server.
 * 
 */

$_SESSION['loggedin'] = TRUE;
$_SESSION['name'] = $_POST['username'];
$_SESSION['id'] = $id;
$_SESSION['role'] = $role;

/**
 * 
 * If the user checked the remember me check box:
 * 
 */

if (isset($_POST['rememberme'])) {

/**
 * 
 * Create a hash that will be stored as a cookie and in the database, 
 * this will be used to identify the user.
 * 
 */

$cookiehash = !empty($rememberme) ? $rememberme : password_hash($id . $_POST['username'] . 'yoursecretkey', PASSWORD_DEFAULT);

/**
 * 
 * The amount of days a user will be remembered:
 * 
 */

$days = 30;
setcookie('rememberme', $cookiehash, (int)(time() + 60 * 60 * 24 * $days));

/**
 * 
 * Update the "rememberme" field in the accounts table.
 * 
 */

$stmt = $conn->prepare('UPDATE accounts SET rememberme = ? WHERE id = ?');
$stmt->bind_param('si', $cookiehash, $id);
$stmt->execute();
$stmt->close(); }
echo 'Success';
echo "<script> window.location.replace('home.php') </script>"; }} 
else {

/**
 * 
 * Incorrect password.
 * 
 */ 

require_once 'plainheader.php'; ?>
<br><br>
<div class="card center gentextcolor"><h3 style="text-align:center" class="linkcolor"><?= _INCORRECTUSERNAMEPASSWORD ?></h3></div>
<br><br>
<?php exit(); }} 
else {
$login_attempts = loginAttempts($conn, TRUE);
require_once 'plainheader.php'; ?>
<h3 class="card center gentextcolor" style="text-align:center;"><?= _INCORRECTUSERNAMEPASSWORD ?> <?= _YOUHAVE ?> <?= $login_attempts['attempts_left'] ?> <?= _ATTEMPTSREMAINING ?></h3><br>
<?php exit(); } ?>