<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 */

include 'main.php';

check_loggedin($conn, 'index.php');
$sql = "SELECT * FROM website"; 
$result = $conn->query($sql); 
if ($result->num_rows > 0) { 
while ($row = $result->fetch_assoc()) { 
require_once 'lang/' . $row['lang'] . '.php'; }}

try {
$pdo = new PDO('mysql:host=' . DB_HOST . ';dbname=' . DB_NAME . ';charset=' . CHARSET, DB_USER, DB_PASSWORD);
$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $exception) {

/**
 * 
 * If there is an error with the connection, 
 * stop the script and display the error.
 * 
 */

exit('Failed to connect to database!'); }

/**
 * 
 * Below function will convert datetime 
 * to time elapsed string.
 * 
 */

function time_elapsed_string($datetime, $full = false) {
$now = new DateTime;
$ago = new DateTime($datetime);
$diff = $now->diff($ago);
@$diff->w = floor($diff->d / 7);
@$diff->d -= $diff->w * 7;
$string = array('y' => 'year', 'm' => 'month', 'w' => 'week', 'd' => 'day', 'h' => 'hour', 'i' => 'minute', 's' => 'second');
foreach ($string as $k => &$v) {
if ($diff->$k) {
$v = $diff->$k . ' ' . $v . ($diff->$k > 1 ? 's' : ''); } 
else {
unset($string[$k]); }}
if (!$full) $string = array_slice($string, 0, 1);
return $string ? implode(', ', $string) . ' ago' : 'just now'; } 

function show_comment($comment, $comments = [], $filters = []) {
// Convert new lines to <br> and escape special characters
$content = nl2br(htmlspecialchars($comment['content'], ENT_QUOTES));
// Allowed html tags, feel free to add tags to the arrays
$content = str_ireplace(
['&lt;i&gt;', '&lt;/i&gt;', '&lt;b&gt;', '&lt;/b&gt;', '&lt;u&gt;', '&lt;/u&gt;', '&lt;code&gt;', '&lt;/code&gt;', '&lt;pre&gt;', '&lt;/pre&gt;'],
['<i>', '</i>', '<b>', '</b>', '<u>', '</u>', '<code>', '</code>', '<pre>', '</pre>'],
$content );

/**
 * 
 * Apply the filters.
 * 
 */

if ($filters) {
$content = str_ireplace(array_column($filters, 'word'), array_column($filters, 'replacement'), $content); }

/**
 * 
 * Comment template.
 * 
 */

$html = '
<div class="comment">
<div class="img">
<img src="' . (!empty($comment['img']) ? htmlspecialchars($comment['img'], ENT_QUOTES) : default_profile_image) . '" width="48" height="48" alt="" . _COMMENTIMAGE . "">
</div>
<div class="con">
<div>
<h3 class="name link">' . htmlspecialchars($comment['name'], ENT_QUOTES) . '</h3>
<span class="date">' . time_elapsed_string($comment['submit_date']) . '</span>
</div>
<p style="font-size:18px" class="comment_content">
' . $content . '
' . ($comment['approved'] ? '' : '<br><br><i>(' . _AWAITINGAPPROVAL . ')</i>') . '
</p>
<div class="comment_footer">
<span class="num">' . $comment['votes'] . '</span>
<a href="#" class="vote" data-vote="up" data-comment-id="' . $comment['id'] . '">
<i class="arrow up"></i>
</a>
<a href="#" class="vote" data-vote="down" data-comment-id="' . $comment['id'] . '">
<i class="arrow down"></i>
</a>
<a class="reply_comment_btn" href="comments.php"" data-comment-id="' . $comment['id'] . '">' . _REPLY . '</a>
</div>
' . show_write_comment_form($comment['id']) . '
<div class="replies">
' . show_comments($comments, $filters, $comment['id']) . '
</div>
</div>
</div>';
return $html; }

function show_comments($comments, $filters, $parent_id = -1) {
$html = '';
if ($parent_id != -1) {
array_multisort(array_column($comments, 'submit_date'), SORT_ASC, $comments); }
foreach ($comments as $comment) {
if ($comment['parent_id'] == $parent_id) {
$html .= show_comment($comment, $comments, $filters); }}
return $html; }

function show_write_comment_form($parent_id = -1) {
$html = '
<div class="write_comment" data-comment-id="' . $parent_id . '">
<form>
<input name="parent_id" type="hidden" value="' . $parent_id . '">
<input type="hidden" name="name" type="text" value="' . $_SESSION['name'] . '" required">
<textarea name="content" placeholder="' . _WRITECOMMENT . '" required></textarea>
<input name="img_url" type="url" placeholder="' . _PHOTOURL . '">
<button type="submit">' . _SUBMIT . '</button>&nbsp;&nbsp;<button><a href="" style="text-decoration:none">Cancel</a></button>
</form>
</div>
';
return $html; }

/**
 * 
 * Page ID needs to exist as it is used 
 * to determine which comments are for which page.
 * 
 */

if (isset($_GET['page_id'])) {

/**
 * 
 * Retrieve the filters.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM filters');
$stmt->execute();
$filters = $stmt->fetchAll(PDO::FETCH_ASSOC);

/**
 * 
 * If the user submits the write comment form.
 * 
 */

if (isset($_POST['name'], $_POST['content'], $_POST['parent_id'], $_POST['img_url'])) {

/**
 * 
 * Insert a new comment.
 * 
 */

$stmt = $pdo->prepare('INSERT INTO comments (page_id, parent_id, name, content, submit_date, img, approved) VALUES (?,?,?,?,NOW(),?,?)');
$approved = comments_approval_required ? 0 : 1;
$stmt->execute([$_GET['page_id'], $_POST['parent_id'], $_POST['name'], $_POST['content'], $_POST['img_url'], $approved]);

/**
 * 
 * Retrieve the comment.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM comments WHERE id = ?');
$stmt->execute([$pdo->lastInsertId()]);
$comment = $stmt->fetch(PDO::FETCH_ASSOC);

/**
 * 
 * Output the comment.
 * 
 */

exit(show_comment($comment)); }

/**
 * 
 * If the user clicks one of the vote buttons.
 * 
 */

if (isset($_GET['vote'], $_GET['comment_id'])) {

/**
 * 
 * Check if the cookie exists for this comment.
 * 
 */

if (!isset($_COOKIE['vote_' . $_GET['comment_id']])) {

/**
 * 
 * Cookie does not exists, 
 * update the votes column 
 * and increment/decrement the value.
 * 
 */

$stmt = $pdo->prepare('UPDATE comments SET votes = votes ' . ($_GET['vote'] == 'up' ? '+' : '-') . ' 1 WHERE id = ?');
$stmt->execute([$_GET['comment_id']]);

/**
 * 
 * Set vote cookie, this will prevent the users from voting multiple times
 * on the same comment, cookie expires in 10 years.
 * 
 */

setcookie('vote_' . $_GET['comment_id'], 'true', time() + (10 * 365 * 24 * 60 * 60), '/'); }

/**
 * 
 * Retrieve the number of votes from the comments table.
 * 
 */

$stmt = $pdo->prepare('SELECT votes FROM comments WHERE id = ?');
$stmt->execute([$_GET['comment_id']]);
$comment = $stmt->fetch(PDO::FETCH_ASSOC);

/**
 * 
 * Output the votes.
 * 
 */

exit($comment['votes']); }

/**
 * 
 * If the limit variables exist, 
 * add the LIMIT clause to the SQL statement.
 * 
 */

$comments_per_pagination_page = isset($_GET['comments_to_show']) ? $_GET['comments_to_show'] : 30;
$limit = isset($_GET['current_pagination_page']) ? 'LIMIT :current_pagination_page' : '';

/**
 * 
 * By default, order by the submit data (newest).
 * 
 */

$sort_by = 'ORDER BY votes DESC, submit_date DESC';
if (isset($_GET['sort_by'])) {

/**
 * 
 * User has changed the sort by, 
 * update the sort_by variable.
 * 
 */

$sort_by = $_GET['sort_by'] == 'newest' ? 'ORDER BY submit_date DESC' : $sort_by;
$sort_by = $_GET['sort_by'] == 'oldest' ? 'ORDER BY submit_date ASC' : $sort_by;
$sort_by = $_GET['sort_by'] == 'votes' ? 'ORDER BY votes DESC, submit_date DESC' : $sort_by; }

/**
 * 
 * Get all comments by the Page ID
 * ordered by the submit date.
 * 
 */

$stmt = $pdo->prepare('SELECT * FROM comments WHERE page_id = :page_id AND approved = 1 ' . $sort_by . ' ' . $limit);
if ($limit) {
$stmt->bindValue(':current_pagination_page', (int)$_GET['current_pagination_page'] * (int)$comments_per_pagination_page, PDO::PARAM_INT); }

/**
 * 
 * Bind the page ID to our query.
 * 
 */

$stmt->bindValue(':page_id', $_GET['page_id'], PDO::PARAM_INT);
$stmt->execute();
$comments = $stmt->fetchAll(PDO::FETCH_ASSOC);

/**
 * 
 * Get the overall rating 
 * and total number of comments.
 * 
 */

$stmt = $pdo->prepare('SELECT COUNT(*) AS total_comments FROM comments WHERE page_id = ? AND approved = 1');
$stmt->execute([$_GET['page_id']]);
$comments_info = $stmt->fetch(PDO::FETCH_ASSOC); } 
else {
exit('No page ID specified!'); } ?>
<div class="comment_header">
<span class="total"><?= $comments_info['total_comments'] ?> <?= _COMMENTS ?></span>
<form>
<label for="sort_by"></label>
<select name="sort_by" id="sort_by">
<option value="" disabled<?= !isset($_GET['sort_by']) ? ' selected' : '' ?>>Sort By</option>
<option value="votes" <?= isset($_GET['sort_by']) && $_GET['sort_by'] == 'votes' ? ' selected' : '' ?>><?= _VOTES ?></option>
<option value="newest" <?= isset($_GET['sort_by']) && $_GET['sort_by'] == 'newest' ? ' selected' : '' ?>><?= _NEWEST ?></option>
<option value="oldest" <?= isset($_GET['sort_by']) && $_GET['sort_by'] == 'oldest' ? ' selected' : '' ?>><?= _OLDEST ?></option>
</select>
</form>
<a href="#" class="write_comment_btn" data-comment-id="-1"><?= _WRITECOMMENT ?></a>
</div>
<?= show_write_comment_form() ?>
<div class="comments_wrapper">
<?= show_comments($comments, $filters) ?>
</div>
<?php if (count($comments) < $comments_info['total_comments']) : ?>
<a href="#" class="show_more_comments"><?= _SHOWMORE ?></a>
<?php endif; ?>