<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 * 
 */
class Message {
    
/**
 * 
 * Connect to the database.
 * 
 */

private $pdo = null;
private $stmt = null;
public $error;
function __construct () {
try {
$this->pdo = new PDO(
"mysql:host=".DB_HOST.";dbname=".DB_NAME.";charset=".DB_CHARSET,
DB_USER, DB_PASSWORD, [
PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC
]);
} catch (Exception $ex) { exit($ex->getMessage()); }}

/**
 * 
 * Close database connection.
 * 
 */

function __destruct () {
if ($this->stmt !== null) { $this->stmt = null; }
if ($this->pdo !== null) { $this->pdo = null; }}

/**
 * 
 * Execute SQL query.
 * 
 */

function exec ($sql, $data=null) {
try {
$this->stmt = $this->pdo->prepare($sql);
$this->stmt->execute($data);
return true;
} catch (Exception $ex) {
$this->error = $ex->getMessage();
return false; }}

/**
 * 
 * (Fetch a single row..
 * 
 */

function fetch ($sql, $data=null) {
if ($this->exec($sql, $data) === false) { return false; }
return $this->stmt->fetch(); }

/**
 * 
 * Fetch all (multiple rows.
 * 
 */

function fetchAll ($sql, $data=null, $key=null) {
if ($this->exec($sql, $data) === false) { return false; }
if ($key === null) { return $this->stmt->fetchAll(); }
else {
$data = [];
while ($r = $this->stmt->fetch()) { $data[$r[$key]] = $r; }
return $data; }}

/**
 * 
 * Get all users and read messages.
 * 
 */

function getUsers ($for=null) {
/**
 * 
 * Get users.
 * 
 */

$users = $this->fetchAll(
"SELECT * FROM `accounts` WHERE `id`!=?",
[$for], "id"
);
if (!is_array($users)) { return false; }

/**
 * 
 * Count unread messages.
 * 
 */

if ($this->exec(
"SELECT `user_from`, COUNT(*) `ur`
FROM `messages` WHERE `user_to`=?
AND `date_read` IS NULL
GROUP BY `user_from`", [$for]) === false) { return false; }
while ($r = $this->stmt->fetch()) {
$users[$r["user_from"]]["unread"] = $r["ur"]; }

/**
 * 
 * Message Results.
 * 
 */

return $users; }

/**
 * 
 * Get Messages..
 * 
 */

function getMsg ($from, $to, $limit=30) {

/**
 * 
 * Mark all as Read.
 * 
 */

if ($this->exec(
"UPDATE `messages` SET `date_read`=NOW()
WHERE `user_from`=? AND `user_to`=? AND `date_read` IS NULL",
[$from, $to]) === false) { return false; }

/**
 * 
 * Get messages.
 * 
 */

return $this->fetchAll(
"SELECT * FROM `messages`
WHERE `user_from` IN (?,?)
AND `user_to` IN (?,?)
ORDER BY `date_send` DESC
LIMIT 0, $limit",
[$from, $to, $from, $to]
);
}

/**
 * 
 * Send a message.
 * 
 */
function send ($from, $to, $msg) {
return $this->exec(
"INSERT INTO `messages` (`user_from`, `user_to`, `message`) VALUES (?,?,?)",
[$from, $to, $msg]
);
}}

/**
 * 
 * Start.
 * 
 */

$MSG = new Message();
