<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 */

require_once 'main.php';
check_loggedin($conn); 

$sql = "SELECT * FROM website, themes"; 
$result = $conn->query($sql);
if ($result->num_rows > 0) {
while ($row = $result->fetch_assoc()) {
$themes = $row['themes']; 
$theme_name = $row['theme_name']; 
$column_title = $row['column_title'];
$allowthemeuse = $row['allowthemeuse'];

require_once 'lang/' . $row['lang'] . '.php'; }}

require_once 'functions.php';

$sql = "SELECT * FROM avatar"; 
$result = $conn->query($sql);
if ($result->num_rows > 0) {
while ($row = $result->fetch_assoc()) { 
$avatar_radius = $row['avatar_radius']; 
$useavatar = $row['useavatar'];}}

// output message (errors, etc)
$msg = '';

$stmt = $conn->prepare('SELECT password, email, activation_code, role, date,  use_avatar, avatarurl, usertheme, usetheme, facebook, youtube, instagram, tiktok, twitter, twitch, showsm, realname, location, bio, interest  FROM accounts WHERE id = ?');

$stmt->bind_param('i', $_SESSION['id']);
$stmt->execute();
$stmt->bind_result(
$password,
$email,
$activation_code,
$role,
$date,
$use_avatar,
$avatarurl,
$usertheme,
$usetheme,
$facebook, 
$youtube, 
$instagram, 
$tiktok, 
$twitter, 
$twitch,
$showsm,
$realname,
$location,
$bio,
$interest
);
$stmt->fetch();
$stmt->close();

/**
 * 
 *  Handle edit profile post data.
 * 
 */

if (isset($_POST['username'], $_POST['password'], $_POST['cpassword'], $_POST['email'])) {

/**
 * 
 *  Make sure the submitted registration values are not empty.
 * 
 */

if (empty($_POST['username']) || empty($_POST['email'])) {
$msg = 'The input fields must not be empty!'; } 

else if (!filter_var($_POST['email'], FILTER_VALIDATE_EMAIL)) {
$msg = 'Please provide a valid email address!'; } 

else if (!preg_match('/^[a-zA-Z0-9]+$/', $_POST['username'])) {
$msg = 'Username must contain only letters and numbers!'; } 

else if (!empty($_POST['password']) && (strlen($_POST['password']) > 20 || strlen($_POST['password']) < 5)) {
$msg = 'Password must be between 5 and 20 characters long!'; } 

else if ($_POST['cpassword'] != $_POST['password']) {
echo '<p style="color:#000">';
$msg = 'Passwords do not match!';
echo '</p>'; }

if (empty($msg)) {

/**
 * 
 *  Check if new username or email already exists in the database.
 * 
 */

$stmt = $conn->prepare('SELECT * FROM accounts WHERE (username = ? OR email = ?) AND username != ? AND email != ?');
$stmt->bind_param('ssss', $_POST['username'], $_POST['email'], $_SESSION['name'], $email);
$stmt->execute();
$stmt->store_result();
if ($stmt->num_rows > 0) {
$msg = '' . _ACCOUNTEXIST . '';
} else {
$stmt->close();
$uniqid = account_activation == 'true' && $email != $_POST['email'] ? uniqid() : $activation_code;
$stmt = $conn->prepare('UPDATE accounts SET username = ?, password = ?, activation_code = ?, use_avatar = ?, avatarurl = ?, usertheme = ?, usetheme = ?, facebook = ?, youtube = ?, instagram = ?, tiktok = ?, twitter = ?, twitch = ?, showsm = ?, realname = ?, location = ?, bio = ?, interest = ?  WHERE id = ?');

$password = !empty($_POST['password']) ? password_hash($_POST['password'], PASSWORD_DEFAULT) : $password;

$stmt->bind_param(
'ssssssssssssssssssi',
$_POST['username'],
$password,
$uniqid,
$_POST['use_avatar'],
$_POST['avatarurl'],
$_POST['usertheme'],
$_POST['usetheme'],
$_POST['facebook'], 
$_POST['youtube'], 
$_POST['instagram'], 
$_POST['tiktok'], 
$_POST['twitter'], 
$_POST['twitch'],
$_POST['showsm'],
$_POST['realname'],
$_POST['location'],
$_POST['bio'],
$_POST['interest'], 
$_SESSION['id']
);
$stmt->execute();
$stmt->close();

$_SESSION['name'] = $_POST['username'];
if (account_activation == 'true' && $email != $_POST['email']) {
send_activation_email($_POST['email'], $uniqid);
unset($_SESSION['loggedin']);
$msg = '' . _HAVECHANGEDEMAIL . '';
} else {
echo "<script> window.location.replace('profile.php') </script>";
exit;}}}} ?>

<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<title><?=_PROFILE?></title>
<script src="jscolor.js"></script>
<?php require_once 'header.php';

if (!isset($_GET['action'])) {

/**
 *  Show the members information.
 *
 */ ?>

<div class="spacer half" style="margin:0 auto">

<div class="center" style="margin:0 auto">

<table class="mini-container spacer radius noborder"><tr><td class="center top" colspan="2">
<hr /><h3 class="center black"><?=_YOURPROFILE?></h3><hr />
<?php if ($useavatar == 'Gravatar') {?>
<p class="center black"><?=_DONTHAVEAVATAR?><a href="https://gravatar.com" target="_blank"><span class="black">Gravatar.com</a></a>)</p>
<?php }?>

<?php if ($useavatar == 'Avatar') {?>
<p class="center black"><?=_ADDAVATAR?></p>
<?php }

if ($useavatar == 'User') { ?>
<p class="center black"><?=_DONTHAVEAVATAR?><a href="https://gravatar.com" target="_blank"><span class="black">Gravatar.com</span></a <?=_ORLINKTOONE?>)</p>
<?php } ?>
<br>
<?php if ($use_avatar == 'Gravatar') {require "Gravatar.php";
global $email;
$g = new Gravatar("$email");
echo $g->toHtml();} 
elseif ($use_avatar == 'Avatar') {?>
<p class="center"><img src="<?=$avatarurl?>" style="width:90px; height:90px; border-radius:<?=$avatar_radius?>; border:0;" alt="" /></p>
<?php } 
elseif ($use_avatar == 'None') {} ?>
<p class="center black" style="text-transform:uppercase;"><?=$_SESSION['name']?></p><br>
</td></tr>
<tr><td class="left black"><strong><?=_USERNAME?>:</strong></td><td class="left black"><?= $_SESSION['name'] ?></td></tr>
<tr><td class="left black"><strong><?=_REALNAME?>:</strong></td><td class="left black"><?= $realname ?></td></tr>
<tr><td class="left black"><strong><?=_LOCATION?>:</strong></td><td class="left black"><?= $location ?></td></tr>
<tr><td class="left black"><strong><?=_EMAIL?>:</strong></td><td class="left black"><?= $email ?></td></tr>
<tr><td class="left black"><strong><?=_ROLE?>:</strong></td><td class="left black"><?= $role ?></td></tr>
<tr><td class="left black"><strong><?=_MEMBERSINCE?>:</strong></td><td class="left black"><?= $date ?></td></tr>
<?php if ($allowthemeuse == 'Yes') { ?>
<tr><td class="left black"><strong><?=_USETHEME?>:</strong></td><td class="left black"><?= $usetheme ?></td></tr>
<tr><td class="left black"><strong><?=_USERTHEME?>:</strong></td><td class="left black"><?= $usertheme ?></td></tr>
<?php } ?>
<tr><td class="left black"><strong><?=_SOCIALMEDIA?>:</strong></td>
<td>
<div class="row left">
<div class="left column6"><?php if ($facebook == '') {} else { echo '<a href="https://facebook.com/' . $facebook . '" target="_blank" title="Facebook"><img src="../core/social icons/facebook.png" style="width:36px; border:0;" alt="Facebook" /></a>'; } ?></div>

<div class="column6"><?php if ($youtube == '') {} else { echo '<a href="https://www.youtube.com/' . $youtube . '" target="_blank" title="YouTube"><img src="../core/social icons/youtube.png" style="width:36px; border:0;" alt="YouTube" /></a>'; } ?></div>

<div class="column6"><?php if ($twitch == '') {} else { echo '<a href="https://www.twitch.tv/' . $twitch . '" target="_blank" title="Twitch"><img src="../core/social icons/twitch.png" style="width:36px; border:0;" alt="Twitch" /></a>'; } ?></div>

<div class="column6"><?php if ($tiktok == '') {} else { echo '<a href="https://tiktok.com/@' . $tiktok . '" target="_blank" title="Tiktok"><img src="../core/social icons/tiktok.png" style="width:36px; border:0;" alt="Tiktok" /></a>'; } ?></div>

<div class="column6"><?php if ($instagram == '') {} else { echo '<a href="https://www.instagram.com/' . $instagram . '" target="_blank" title="Instagram"><img src="../core/social icons/instagram.png" style="width:36px; border:0;" alt="Instagram" /></a>'; } ?></div>

<div class="column6"><?php if ($twitter == '') {} else { echo '<a href="https://twitter.com/' . $twitter . '" target="_blank" title="Twitter"><img src="../core/social icons/twitter.png" style="width:36px; border:0;" alt="Twitter" /> </a>'; } ?></div>
</div>

</td></tr>

<tr><td colspan="2" class="left black"><strong><?=_BIO?>:</strong><br><div class="card"><?= $bio ?></div></td></tr>

<tr><td colspan="2" class="left black"><strong><?=_INTEREST?>:</strong><br><div class="left card spacer"><?= $interest ?></div></td></tr>

<tr><td colspan="2">

<div class="spacer center"><a href="profile.php?action=edit" style="text-decoration:none;margin:0 auto; width:250px;" class="button center spacer"><span class="spacer linkcolor"><?= _EDITDETAILS ?></span></a></div>
</td></tr></table>
</div>
</div>
<br><br>

<?php 
/**
 *
 * Edit the profile ----------------------------
 *
 */

} elseif ($_GET['action'] == 'edit') { ?>
<style>.profile-container {background:#f1f1f1; font-size:20px; color:#000; padding:10px;}</style>
</head>
<body>
<div class="profile-container full">
<div class="spacer radius respblock">
<hr /><h3 class="center black"><?=_EDITYOURPROFILE?></h3><hr />
<?php
/**
 * Build user information.
 *
 */ ?>

<p class="center spacer" style="font-size:18px"><?=$msg?></p>
<div class="mini-container center noborder">

<form action="profile.php?action=edit" method="post">

<?php saveprofile();

/**
 * 
 * Edit members personal information.
 * 
 */ ?>

<hr /><h3 id="avatar" style="background:#f0f0f0" class="spacer black"><?=_AVATARSETTINGS ?></h3><hr />

<?php if ($useavatar == 'User') {?>
<p id="avatar" class="black center"><?=_IFAVATARISSELECTED?></p>

<p class="black"><strong><?=_CHOOSEAVATARTYPE?></strong>
<select name="use_avatar">
<option><?=$use_avatar?></option>
<option value="Gravatar">Gravatar</option>
<option value="Avatar">Avatar</option>
<option value="None"><?=_NONE?></option>
</select></p>

<strong><?=_AVATAR?>:</strong><br>
<input type="text" maxlength="255" style="width:100%" name="avatarurl" id="avatarurl" value="<?=$avatarurl?>" placeholder="<?=_AVATAR?>">
<?php }

if ($useavatar == 'Avatar') { ?>
<i class="fa fa-user"></i> <?=_AVATAR?>: <br>
<input type="text" maxlength="255" style="width:100%" name="avatarurl" id="avatarurl" value="<?=$avatarurl?>" placeholder="<?=_AVATAR?>">
<br>
<?php } ?>
<br><br>
</div>
<br>
<div class="mini-container center noborder">

<hr /><h3 id="mbrsettings" style="background:#f0f0f0" class="spacer black"><?=_MBRSETTINGS?></h3><hr />

<strong><?=_USERNAME?>:</strong><br>
<input type="text" value="<?=$_SESSION['name']?>" name="username" id="username" placeholder="<?=_USERNAME?>">
<br>
<strong><?=_PASSWORD?>:</strong><br><small><?=_ONLYIFCHANGING?></small><br>
<input style="resize:none" maxlength="25" rows="1" name="password" id="password" placeholder="<?=_PASSWORD?>">
<br>
<strong><?=_CONFIRMPASSWORD?>:</strong><br><small><?=_ONLYIFCHANGING?></small><br>
<input style="resize:none" maxlength="25" rows="1" name="cpassword" id="cpassword" placeholder="<?=_CONFIRMPASSWORD?>">
<br><br>
<p class="black"><i class="fa fa-envelope"></i> <?=_EMAIL?>:
<input name="email" class="full" maxlength="255" rows="1" type="hidden" value="<?=$email?>"><strong><?=$email?></strong> <?=_CANNOTBECHANGED?>
</p>
</div>
<br>
<div class="mini-container center noborder">
<hr /><h3  style="background:#f0f0f0" class="spacer black"><?= _OPTIONALINFO ?></h3><hr />
<p class="center black"><strong><?= _ANYTHINGADDED ?></strong></p>

<p class="left black"><?= _REALNAME ?>: <input maxlength="25" size="25" rows="1" name="realname" value="<?= $realname ?>"></p>
<p class="left black"><?= _LOCATION ?>:&nbsp;&nbsp;&nbsp; <input maxlength="25" size="25" rows="1" name="location" value="<?= $location ?>"></p>

<?= _BIO_MAX ?>: <textarea id="editor" type="text" name="bio" maxlength="1500" size="1500" style="height:320px"><?=$bio?></textarea>

<?= _INTEREST_MAX ?>: <textarea id="editor" type="text" name="interest" maxlength="500" size="500" style="height:140px"><?=$interest?></textarea>

<br>

</div>
<br>
<div class="mini-container center noborder">
<hr /><h3 id="sm" style="background:#f0f0f0" class="spacer black"><?= _SOCIAL_MEDIA ?></h3><hr />
<p class="black"><strong><?= _MEMBERSLIST ?></strong> 
<select name="showsm">
<option><?=$showsm?></option>
<option value="Yes"><?=_YES?></option>
<option value="No"><?=_NO?></option>
</select> <?= _ACCOUNTSWILLSHOW ?></p>

<h3 class="center black"><?= _ACCOUNTNUMBERNAME ?></h3>

<table><tr style="width:100%">
<td>Facebook: </td><td><input maxlength="25" rows="1" name="facebook" style="width:100%" value="<?= $facebook ?>"></td></tr>

<tr><td>YouTube: </td><td><input maxlength="25" rows="1" name="youtube" style="width:100%" value="<?= $youtube ?>"></td></tr>

<tr><td>Instagram: </td><td><input maxlength="25" rows="1" name="instagram" style="width:100%" value="<?= $instagram ?>"></td></tr>

<tr><td>TikTok: </td><td><input maxlength="25" rows="1" name="tiktok" style="width:100%" value="<?= $tiktok ?>"></td></tr>

<tr><td>Twitter: </td><td><input maxlength="25" rows="1" name="twitter" style="width:100%" value="<?= $twitter ?>"></td></tr>

<tr><td>Twitch: </td><td><input maxlength="25" rows="1" name="twitch" style="width:100%" value="<?= $twitch ?>"></td></tr>
</table>
<br>

<?php
/**
 * 
 * Choose theme.
 * 
 */ ?>

</div>
<br>
<?php if ($allowthemeuse == 'Yes') { ?>
<div class="mini-container center noborder">
<div class="center" id="theme">
<hr /><h3 style="background:#f0f0f0" class="spacer black"><?= _THEMESELECTION ?></h3><hr />
</div>
<table><tr><td class="top">
<p class="black"><strong><?=_USETHEME?>?</strong> <select name="usetheme">
<option><?=$usetheme?></option>
<option value="Yes"><?=_YES?></option>
<option value="No"><?=_NO?></option>
</select></p>
<?php $sql = "SELECT * FROM themes ORDER BY theme_name ASC"; $result = $conn->query($sql);if ($result->num_rows > 0) {?>
<p class="black center"><strong><?=_USERTHEME?>: </strong>
<select name="usertheme">
<option><?=$usertheme?></option>
<?php while ($row = $result->fetch_assoc()) {?>
<option value="<?=$row['theme_name']?>">
<?=$row['theme_name']?>
</option>
<?php }?>
</select>
</p>
<?php } ?>
</td><td>
<p class="black center"><strong><?=_PREVIEWTHEMES?></strong></p>
<div style="height:200px; overflow-y:auto">
<?php $sql = "SELECT theme_name, id FROM themes ORDER BY theme_name ASC"; $result = $conn->query($sql);if ($result->num_rows > 0) {while ($row = $result->fetch_assoc()) {?>
<p class="left"><a href="../sup/themepreview.php?id=<?=$row['id']?>" target="_blank" style="text-decoration:none"><span class="black">&bull; <?=$row['theme_name'];}}?></span></a></p>
</div>
</td></tr></table>
</div>
<?php } ?>
<br>

<?php } ?>

</div>
</div>
</div>

<?php require_once 'footer.php'; ?>