<?php
/**
 * Spectra CMS is software designed to build a website.
 * PHP version 8+
 *
 * @category  OpenSource
 * @package   Spectra CMS
 * @author    Mike Boyles <admin@papamikescreations.org>
 * @copyright 2024 Papa Mike's Creations
 * @license   GNU General Public License <http://www.gnu.org/licenses/>.
 * @link      https://www.papamikescreations.org
 */

include 'main.php';

$sql = "SELECT * FROM website"; 
$result = $conn->query($sql); 
if ($result->num_rows > 0) { 
while ($row = $result->fetch_assoc()) {
require_once 'lang/' . $row['lang'] . '.php'; }}
if (mysqli_connect_errno()) {

/**
 * 
 * If there is an error with the connection, 
 * stop the script and display the error.
 * 
 */

exit('Failed to connect to MySQL: ' . mysqli_connect_error()); }

/**
 * 
 * Now we check if the data was submitted, 
 * isset() function will check if the data exists.
 * 
 */

if (!isset($_POST['username'], $_POST['password'], $_POST['cpassword'], $_POST['email'])) {

/**
 * 
 * Could not get the data that should have been sent.
 * 
 */

echo '' . _PLEASECOMPLETEREGFORM . '';
exit(); }

/**
 * 
 * Make sure the submitted registration values are not empty.
 * 
 */

if (empty($_POST['username']) || empty($_POST['password']) || empty($_POST['email'])) {

/**
 * 
 * One or more values are empty.
 * 
 */

echo '' . _PLEASECOMPLETEREGFORM . '';
exit(); }

/**
 * 
 * Check to see if the email is valid.
 * 
 */

if (!filter_var($_POST['email'], FILTER_VALIDATE_EMAIL)) {
echo '' . _EMAILNOTVALID . '';
exit(); }

/**
 * 
 * Username must contain only characters and numbers.
 * 
 */

if (!preg_match('/^[a-zA-Z0-9]+$/', $_POST['username'])) {
echo '' . _USERNAMENOTVALID . '';
exit(); }

/**
 * 
 * Password must be between 5 and 20 characters long.
 * 
 */

if (strlen($_POST['password']) > 20 || strlen($_POST['password']) < 5) {
echo '' . _PASSWORDSMUSTBEBETWEEN . '';
exit(); }

/**
 * 
 * Check if both the password and confirm password fields match.
 * 
 */

if ($_POST['cpassword'] != $_POST['password']) {
echo '' . _PASSWORDSDONOTMATCH . '';
exit(); }

/**
 * 
 * We need to check if the account with that username exists.
 * 
 */

$stmt = $conn->prepare('SELECT id, password FROM accounts WHERE username = ? OR email = ?');

/**
 * 
 * Bind parameters (s = string, i = int, b = blob, etc),
 * hash the password using the PHP password_hash function.
 * 
 */

$stmt->bind_param('ss', $_POST['username'], $_POST['email']);
$stmt->execute();
$stmt->store_result();

/**
 * 
 * Store the result so we can check if the account exists in the database.
 * 
 */

if ($stmt->num_rows > 0) {

/**
 * 
 * Username already exists.
 * 
 */ ?>

<?= _USERNAMEEMAILEXISTS ?>';
<?php } 
else {
$stmt->close();

/**
 * 
 * Username doesnt exists, insert new account.
 * 
 */

$stmt = $conn->prepare('INSERT INTO accounts (username, password, email, activation_code) VALUES (?, ?, ?, ?)');

/**
 * 
 *  We do not want to expose passwords in our database, 
 * so hash the password and use password_verify when a user logs in.
 * 
 */

$password = password_hash($_POST['password'], PASSWORD_DEFAULT);
$uniqid = account_activation == 'true' ? uniqid() : 'activated';
$stmt->bind_param('ssss', $_POST['username'], $password, $_POST['email'], $uniqid);
$stmt->execute();
$stmt->close();
if (account_activation == 'true') {

/**
 * 
 * Account activation required, 
 * send the user the activation email with the "send_activation_email" 
 * function from the "main.php" file.
 * 
 */

send_activation_email($_POST['email'], $uniqid); ?>
<p><?= _CHECKEMAILANDSPAM ?></p>
<?php } 
else { ?>
<p><?= _SUCCESSFULLYREGISTERED ?></p>
<?php }} ?>